==> ph-xsds-xades132-2.6.0-sources.jar: com/helger/xsds/xades132/CertifiedRoleTypeV2.java <==

package com.helger.xsds.xades132;

import java.io.Serializable;
import javax.annotation.Nonnull;
import javax.annotation.Nullable;
import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;
import com.helger.commons.annotation.CodingStyleguideUnaware;
import com.helger.commons.annotation.ReturnsMutableCopy;
import com.helger.commons.equals.EqualsHelper;
import com.helger.commons.hashcode.HashCodeGenerator;
import com.helger.commons.lang.IExplicitlyCloneable;
import com.helger.commons.string.ToStringGenerator;


/**
 * <p>Java class for CertifiedRoleTypeV2 complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="CertifiedRoleTypeV2"&gt;
 *   &lt;complexContent&gt;
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType"&gt;
 *       &lt;choice&gt;
 *         &lt;element ref="{http://uri.etsi.org/01903/v1.3.2#}X509AttributeCertificate"/&gt;
 *         &lt;element ref="{http://uri.etsi.org/01903/v1.3.2#}OtherAttributeCertificate"/&gt;
 *       &lt;/choice&gt;
 *     &lt;/restriction&gt;
 *   &lt;/complexContent&gt;
 * &lt;/complexType&gt;
 * </pre>
 * <p>This class was annotated by ph-jaxb22-plugin -Xph-annotate</p>
 * <p>This class contains methods created by ph-jaxb22-plugin -Xph-equalshashcode</p>
 * <p>This class contains methods created by ph-jaxb22-plugin -Xph-tostring</p>
 * <p>This class contains methods created by ph-jaxb22-plugin -Xph-cloneable2</p>
 * <p>This class contains methods created by ph-jaxb22-plugin -Xph-value-extender</p>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "CertifiedRoleTypeV2", propOrder = {
    "x509AttributeCertificate",
    "otherAttributeCertificate"
})
@CodingStyleguideUnaware
public class CertifiedRoleTypeV2 implements Serializable, IExplicitlyCloneable
{

    @XmlElement(name = "X509AttributeCertificate")
    private EncapsulatedPKIDataType x509AttributeCertificate;
    @XmlElement(name = "OtherAttributeCertificate")
    private AnyType otherAttributeCertificate;

    /**
     * Default constructor<br>
     * Note: automatically created by ph-jaxb22-plugin -Xph-value-extender
     * 
     */
    public CertifiedRoleTypeV2() {
    }

    /**
     * Gets the value of the x509AttributeCertificate property.
     * 
     * @return
     *     possible object is
     *     {@link EncapsulatedPKIDataType }
     *     
     */
    @Nullable
    public EncapsulatedPKIDataType getX509AttributeCertificate() {
        return x509AttributeCertificate;
    }

    /**
     * Sets the value of the x509AttributeCertificate property.
     * 
     * @param value
     *     allowed object is
     *     {@link EncapsulatedPKIDataType }
     *     
     */
    public void setX509AttributeCertificate(
        @Nullable
        EncapsulatedPKIDataType value) {
        this.x509AttributeCertificate = value;
    }

    /**
     * Gets the value of the otherAttributeCertificate property.
     * 
     * @return
     *     possible object is
     *     {@link AnyType }
     *     
     */
    @Nullable
    public AnyType getOtherAttributeCertificate() {
        return otherAttributeCertificate;
    }

    /**
     * Sets the value of the otherAttributeCertificate property.
     * 
     * @param value
     *     allowed object is
     *     {@link AnyType }
     *     
     */
    public void setOtherAttributeCertificate(
        @Nullable
        AnyType value) {
        this.otherAttributeCertificate = value;
    }

    /**
     * Created by ph-jaxb22-plugin -Xph-equalshashcode
     * 
     */
    @Override
    public boolean equals(final Object o) {
        if (o == this) {
            return true;
        }
        if ((o == null)||(!getClass().equals(o.getClass()))) {
            return false;
        }
        final CertifiedRoleTypeV2 rhs = ((CertifiedRoleTypeV2) o);
        if (!EqualsHelper.equals(otherAttributeCertificate, rhs.otherAttributeCertificate)) {
            return false;
        }
        if (!EqualsHelper.equals(x509AttributeCertificate, rhs.x509AttributeCertificate)) {
            return false;
        }
        return true;
    }

    /**
     * Created by ph-jaxb22-plugin -Xph-equalshashcode
     * 
     */
    @Override
    public int hashCode() {
        return new HashCodeGenerator(this).append(otherAttributeCertificate).append(x509AttributeCertificate).getHashCode();
    }

    /**
     * Created by ph-jaxb22-plugin -Xph-tostring
     * 
     */
    @Override
    public String toString() {
        return new ToStringGenerator(this).append("otherAttributeCertificate", otherAttributeCertificate).append("x509AttributeCertificate", x509AttributeCertificate).getToString();
    }

    /**
     * This method clones all values from <code>this</code> to the passed object. All data in the parameter object is overwritten!Created by ph-jaxb22-plugin -Xph-cloneable2
     * 
     * @param ret
     *     The target object to clone to. May not be <code>null</code>.
     */
    public void cloneTo(
        @Nonnull
        CertifiedRoleTypeV2 ret) {
        ret.otherAttributeCertificate = ((otherAttributeCertificate == null)?null:otherAttributeCertificate.clone());
        ret.x509AttributeCertificate = ((x509AttributeCertificate == null)?null:x509AttributeCertificate.clone());
    }

    /**
     * Created by ph-jaxb22-plugin -Xph-cloneable2
     * 
     * @return
     *     The cloned object. Never <code>null</code>.
     */
    @Nonnull
    @ReturnsMutableCopy
    @Override
    public CertifiedRoleTypeV2 clone() {
        CertifiedRoleTypeV2 ret = new CertifiedRoleTypeV2();
        cloneTo(ret);
        return ret;
    }

    /**
     * Special setter with value of type byte[]<br>
     * Note: automatically created by ph-jaxb22-plugin -Xph-value-extender
     * 
     * @param valueParam
     *     The value to be set. May be <code>null</code>.
     * @return
     *     The created intermediary object of type EncapsulatedPKIDataType and never <code>null</code>
     */
    @Nonnull
    public EncapsulatedPKIDataType setX509AttributeCertificate(
        @Nullable
        final byte[] valueParam) {
        EncapsulatedPKIDataType aObj = getX509AttributeCertificate();
        if (aObj == null) {
            aObj = new EncapsulatedPKIDataType(valueParam);
            setX509AttributeCertificate(aObj);
        } else {
            aObj.setValue(valueParam);
        }
        return aObj;
    }

    /**
     * Get the value of the contained EncapsulatedPKIDataType object<br>
     * Note: automatically created by ph-jaxb22-plugin -Xph-value-extender
     * 
     * @return
     *     Either the value of the contained EncapsulatedPKIDataType object or <code>null</code>
     */
    @Nullable
    public byte[] getX509AttributeCertificateValue() {
        EncapsulatedPKIDataType aObj = getX509AttributeCertificate();
        return (aObj == null)?null:aObj.getValue();
    }

}

==> ph-xsds-xades132-3.0.0-sources.jar: com/helger/xsds/xades132/CertifiedRoleTypeV2.java <==

package com.helger.xsds.xades132;

import java.io.Serializable;
import javax.annotation.Nonnull;
import javax.annotation.Nullable;
import com.helger.commons.annotation.CodingStyleguideUnaware;
import com.helger.commons.annotation.ReturnsMutableCopy;
import com.helger.commons.equals.EqualsHelper;
import com.helger.commons.hashcode.HashCodeGenerator;
import com.helger.commons.lang.IExplicitlyCloneable;
import com.helger.commons.string.ToStringGenerator;
import jakarta.xml.bind.annotation.XmlAccessType;
import jakarta.xml.bind.annotation.XmlAccessorType;
import jakarta.xml.bind.annotation.XmlElement;
import jakarta.xml.bind.annotation.XmlType;


/**
 * <p>Java class for CertifiedRoleTypeV2 complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>{@code
 * <complexType name="CertifiedRoleTypeV2">
 *   <complexContent>
 *     <restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       <choice>
 *         <element ref="{http://uri.etsi.org/01903/v1.3.2#}X509AttributeCertificate"/>
 *         <element ref="{http://uri.etsi.org/01903/v1.3.2#}OtherAttributeCertificate"/>
 *       </choice>
 *     </restriction>
 *   </complexContent>
 * </complexType>
 * }</pre>
 * <p>This class was annotated by ph-jaxb-plugin -Xph-annotate</p>
 * <p>This class contains methods created by ph-jaxb-plugin -Xph-equalshashcode</p>
 * <p>This class contains methods created by ph-jaxb-plugin -Xph-tostring</p>
 * <p>This class contains methods created by ph-jaxb-plugin -Xph-cloneable2</p>
 * <p>This class contains methods created by ph-jaxb-plugin -Xph-value-extender</p>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "CertifiedRoleTypeV2", propOrder = {
    "x509AttributeCertificate",
    "otherAttributeCertificate"
})
@CodingStyleguideUnaware
public class CertifiedRoleTypeV2 implements Serializable, IExplicitlyCloneable
{

    @XmlElement(name = "X509AttributeCertificate")
    private EncapsulatedPKIDataType x509AttributeCertificate;
    @XmlElement(name = "OtherAttributeCertificate")
    private AnyType otherAttributeCertificate;

    /**
     * Default constructor<br>
     * Note: automatically created by ph-jaxb-plugin -Xph-value-extender
     * 
     */
    public CertifiedRoleTypeV2() {
    }

    /**
     * Gets the value of the x509AttributeCertificate property.
     * 
     * @return
     *     possible object is
     *     {@link EncapsulatedPKIDataType }
     *     
     */
    @Nullable
    public EncapsulatedPKIDataType getX509AttributeCertificate() {
        return x509AttributeCertificate;
    }

    /**
     * Sets the value of the x509AttributeCertificate property.
     * 
     * @param value
     *     allowed object is
     *     {@link EncapsulatedPKIDataType }
     *     
     */
    public void setX509AttributeCertificate(
        @Nullable
        EncapsulatedPKIDataType value) {
        this.x509AttributeCertificate = value;
    }

    /**
     * Gets the value of the otherAttributeCertificate property.
     * 
     * @return
     *     possible object is
     *     {@link AnyType }
     *     
     */
    @Nullable
    public AnyType getOtherAttributeCertificate() {
        return otherAttributeCertificate;
    }

    /**
     * Sets the value of the otherAttributeCertificate property.
     * 
     * @param value
     *     allowed object is
     *     {@link AnyType }
     *     
     */
    public void setOtherAttributeCertificate(
        @Nullable
        AnyType value) {
        this.otherAttributeCertificate = value;
    }

    /**
     * Created by ph-jaxb-plugin -Xph-equalshashcode
     * 
     */
    @Override
    public boolean equals(final Object o) {
        if (o == this) {
            return true;
        }
        if ((o == null)||(!getClass().equals(o.getClass()))) {
            return false;
        }
        final CertifiedRoleTypeV2 rhs = ((CertifiedRoleTypeV2) o);
        if (!EqualsHelper.equals(otherAttributeCertificate, rhs.otherAttributeCertificate)) {
            return false;
        }
        if (!EqualsHelper.equals(x509AttributeCertificate, rhs.x509AttributeCertificate)) {
            return false;
        }
        return true;
    }

    /**
     * Created by ph-jaxb-plugin -Xph-equalshashcode
     * 
     */
    @Override
    public int hashCode() {
        return new HashCodeGenerator(this).append(otherAttributeCertificate).append(x509AttributeCertificate).getHashCode();
    }

    /**
     * Created by ph-jaxb-plugin -Xph-tostring
     * 
     */
    @Override
    public String toString() {
        return new ToStringGenerator(this).append("otherAttributeCertificate", otherAttributeCertificate).append("x509AttributeCertificate", x509AttributeCertificate).getToString();
    }

    /**
     * This method clones all values from <code>this</code> to the passed object. All data in the parameter object is overwritten!Created by ph-jaxb-plugin -Xph-cloneable2
     * 
     * @param ret
     *     The target object to clone to. May not be <code>null</code>.
     */
    public void cloneTo(
        @Nonnull
        CertifiedRoleTypeV2 ret) {
        ret.otherAttributeCertificate = ((otherAttributeCertificate == null)?null:otherAttributeCertificate.clone());
        ret.x509AttributeCertificate = ((x509AttributeCertificate == null)?null:x509AttributeCertificate.clone());
    }

    /**
     * Created by ph-jaxb-plugin -Xph-cloneable2
     * 
     * @return
     *     The cloned object. Never <code>null</code>.
     */
    @Nonnull
    @ReturnsMutableCopy
    @Override
    public CertifiedRoleTypeV2 clone() {
        CertifiedRoleTypeV2 ret = new CertifiedRoleTypeV2();
        cloneTo(ret);
        return ret;
    }

    /**
     * Special setter with value of type byte[]<br>
     * Note: automatically created by ph-jaxb-plugin -Xph-value-extender
     * 
     * @param valueParam
     *     The value to be set. May be <code>null</code>.
     * @return
     *     The created intermediary object of type EncapsulatedPKIDataType and never <code>null</code>
     */
    @Nonnull
    public EncapsulatedPKIDataType setX509AttributeCertificate(
        @Nullable
        final byte[] valueParam) {
        EncapsulatedPKIDataType aObj = getX509AttributeCertificate();
        if (aObj == null) {
            aObj = new EncapsulatedPKIDataType(valueParam);
            setX509AttributeCertificate(aObj);
        } else {
            aObj.setValue(valueParam);
        }
        return aObj;
    }

    /**
     * Get the value of the contained EncapsulatedPKIDataType object<br>
     * Note: automatically created by ph-jaxb-plugin -Xph-value-extender
     * 
     * @return
     *     Either the value of the contained EncapsulatedPKIDataType object or <code>null</code>
     */
    @Nullable
    public byte[] getX509AttributeCertificateValue() {
        EncapsulatedPKIDataType aObj = getX509AttributeCertificate();
        return (aObj == null)?null:aObj.getValue();
    }

}
